@@ -8,6 +8,7 @@ from bson import ObjectId
 
 class Const:
     class State:
+        BACK_LOG = "back_log"
         TODO = "todo"
         INPROGRESS = "inprogress"
         DONE = "done"
@@ -22,6 +23,8 @@ class Const:
     CONDITIONS = "conditions"
     TIME_IN = "time_in"
     TIME_OUT = "time_out"
+    WORKER_TYPE = "worker_type"
+    REDUCER = "reducer"
 
 
 def ISODate():
@@ -32,6 +35,8 @@ def ISODate():
 class Conditions:
     time_in: datetime = None
     time_out: datetime = None
+    worker_type: str = None
+    reducer: str = None
 
     def to_query(self):
         query = {}
@@ -42,8 +47,15 @@ class Conditions:
         if self.time_out:
             query.update({Const.TIME_OUT: self.time_out})
 
+        if worker_type:
+            query.update({Const.WORKER_TYPE: self.worker_type})
+
+        if reducer:
+            query.update({Const.REDUCER: self.reducer})
+
         if query:
             return {Const.CONDITIONS: query}
+
         return query
 
     @staticmethod
@@ -120,7 +132,17 @@ class RSQ:
         doc[Const.ID] = str(doc[Const.ID])
         return doc
 
+    def reducers(self, _id: str):
+        return self.list_task(
+            state=Const.State.DONE,
+            additional_query={f"{Const.CONDITIONS}.{Const.REDUCER}": _id},
+        )
+
     def done(self, _id: str, result=None):
+
+        for reducer in self.reducers(_id):
+            self.reset(_id=reducer, state=Const.State.TODO)
+
         return self.collection.find_one_and_update(
             {Const.ID: ObjectId(_id)},
             {"$set": {Const.STATE: Const.State.DONE, Const.RESULT: result}},
